/*********************************************
* vim: set sw=8 ts=8 si et :
* Author: Guido Socher, Copyright: GPL 
* This program is to test the led connected to LEDOUT (see below)
* 
* Clock frequency     : Internal clock 1 Mhz (factory default)
*********************************************/
#include <avr/io.h>
#define F_CPU 1000000UL  // 1 MHz
#include <avr/interrupt.h>

#define LEDOUT PORTC5
#define LEDPORT PORTC
#define LEDDDR DDRC
#define LEDDDRPIN DDC5

//#define LEDOUT PORTD5
//#define LEDPORT PORTD
//#define LEDDDR DDRD
//#define LEDDDRPIN DDD5

/* enable pin as output: */
#define LED_INIT LEDDDR|=(1<<LEDDDRPIN)
#define LEDON LEDPORT&=~(1<<LEDOUT)
#define LEDOFF LEDPORT|=(1<<LEDOUT)

static volatile uint8_t cnt2step=0;

// This function gets now called in 20Hz intervals
// It is our interrupt service routine
ISR(TIMER2_COMP_vect){
        cnt2step++;
        if (cnt2step>=10){
                if (PORTC&(1<<PORTC5)){
                        LEDON;
                }else{
                        LEDOFF;
                }
		cnt2step=0;
        }
}

/* setup timer T2 as an interrupt generating time base.
* You must call once sei() in the main program */
void init_cnt2(void)
{
        cnt2step=0;
        TIMSK=(1<<OCIE2); // compare match on OCR2
        TCNT2=0;  // init counter
        OCR2=195; // value to compare against 3906Hz/195=20Hz
        TCCR2=(1<<WGM21); // do not change any output pin, clear at compare match with OCR2
        // divide clock by 256: 1MHz/256=3906.25Hz
        TCCR2|=(1<<CS02)|(1<<CS01)|(0<<CS00); // clock divider, start counter
}


int main(void)
{
        LED_INIT;
        LEDOFF;
	init_cnt2();
        sei();

        while (1) {
        }
        return(0);
}

